#

##

##

##

    	essential nutrients

    		{ 'names': { '$in': [ "calories" ] } }

    		import goodest.adventures.monetary.DB.goodest_tract._land.insert_document as _land_insert_document
    		_land_insert_document.smoothly (
    			collection,
    			document = {},

    			add_region = True
    		)

    	summary

    		"accepts" exists because for example:

    			example 1:
    				B6 is an EN.
    				Pyridoxine is one form of EN.
    				Pyridoxine is not an EN.

    	questions
    		sugars, total including nlea

    	important

    		B6:
    			https://en.wikipedia.org/wiki/Vitamin_B6

    			A group of six chemically similar compounds.

    			Accepts Vitamers:

    				Vitamers:
    					# forms

    					pyridoxal 5-phosphate

    					Pyridoxine
    						https://en.wikipedia.org/wiki/Pyridoxine

    				Potatoe with Skin:
    					|
    					└─  B6:
    						 |
    						 ├─ Pyridoxine:
    						 ├─	Pyridoxamine
    						 ├─ Pyridoxal
    						 ├─